pub struct TrackedBit { /* private fields */ }Expand description
An identifier for a pytket bit register in the data carried by a wire.
After a pytket circuit assigns a new value to the register, older
TrackedBits referring to it become outdated.
Outdated values no longer correspond to a pytket circuit register, but they can still be found in the wires of the hugr being extracted.
Implementations
Sourceimpl TrackedBit
impl TrackedBit
Sourcepub fn pytket_register(&self) -> &PytketRegister
pub fn pytket_register(&self) -> &PytketRegister
Returns the pytket register for this tracked element.
Sourcepub fn pytket_register_arc(&self) -> Arc<PytketRegister> ⓘ
pub fn pytket_register_arc(&self) -> Arc<PytketRegister> ⓘ
Returns the pytket register for this tracked element.
Sourcepub fn is_outdated(&self) -> bool
pub fn is_outdated(&self) -> bool
Returns true if the element has been overwritten by a new value.