#[non_exhaustive]pub enum OpType {
Show 22 variants
Module(Module),
FuncDefn(FuncDefn),
FuncDecl(FuncDecl),
AliasDecl(AliasDecl),
AliasDefn(AliasDefn),
Const(Const),
Input(Input),
Output(Output),
Call(Call),
CallIndirect(CallIndirect),
LoadConstant(LoadConstant),
LoadFunction(LoadFunction),
DFG(DFG),
ExtensionOp(ExtensionOp),
OpaqueOp(OpaqueOp),
Tag(Tag),
DataflowBlock(DataflowBlock),
ExitBlock(ExitBlock),
TailLoop(TailLoop),
CFG(CFG),
Conditional(Conditional),
Case(Case),
}Expand description
The concrete operation types for a node in the HUGR.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Module(Module)
FuncDefn(FuncDefn)
FuncDecl(FuncDecl)
AliasDecl(AliasDecl)
AliasDefn(AliasDefn)
Const(Const)
Input(Input)
Output(Output)
Call(Call)
CallIndirect(CallIndirect)
LoadConstant(LoadConstant)
LoadFunction(LoadFunction)
DFG(DFG)
ExtensionOp(ExtensionOp)
OpaqueOp(OpaqueOp)
Tag(Tag)
DataflowBlock(DataflowBlock)
ExitBlock(ExitBlock)
TailLoop(TailLoop)
CFG(CFG)
Conditional(Conditional)
Case(Case)
Implementations
Sourceimpl OpType
impl OpType
Sourcepub fn as_func_defn(&self) -> Option<&FuncDefn>
pub fn as_func_defn(&self) -> Option<&FuncDefn>
If is an instance of FuncDefn return a reference to it.
Sourcepub fn is_func_defn(&self) -> bool
pub fn is_func_defn(&self) -> bool
Returns true if the operation is an instance of FuncDefn.
Sourceimpl OpType
impl OpType
Sourcepub fn as_func_decl(&self) -> Option<&FuncDecl>
pub fn as_func_decl(&self) -> Option<&FuncDecl>
If is an instance of FuncDecl return a reference to it.
Sourcepub fn is_func_decl(&self) -> bool
pub fn is_func_decl(&self) -> bool
Returns true if the operation is an instance of FuncDecl.
Sourceimpl OpType
impl OpType
Sourcepub fn as_alias_decl(&self) -> Option<&AliasDecl>
pub fn as_alias_decl(&self) -> Option<&AliasDecl>
If is an instance of AliasDecl return a reference to it.
Sourcepub fn is_alias_decl(&self) -> bool
pub fn is_alias_decl(&self) -> bool
Returns true if the operation is an instance of AliasDecl.
Sourceimpl OpType
impl OpType
Sourcepub fn as_alias_defn(&self) -> Option<&AliasDefn>
pub fn as_alias_defn(&self) -> Option<&AliasDefn>
If is an instance of AliasDefn return a reference to it.
Sourcepub fn is_alias_defn(&self) -> bool
pub fn is_alias_defn(&self) -> bool
Returns true if the operation is an instance of AliasDefn.
Sourceimpl OpType
impl OpType
Sourcepub fn as_call_indirect(&self) -> Option<&CallIndirect>
pub fn as_call_indirect(&self) -> Option<&CallIndirect>
If is an instance of CallIndirect return a reference to it.
Sourcepub fn is_call_indirect(&self) -> bool
pub fn is_call_indirect(&self) -> bool
Returns true if the operation is an instance of CallIndirect.
Sourceimpl OpType
impl OpType
Sourcepub fn as_load_constant(&self) -> Option<&LoadConstant>
pub fn as_load_constant(&self) -> Option<&LoadConstant>
If is an instance of LoadConstant return a reference to it.
Sourcepub fn is_load_constant(&self) -> bool
pub fn is_load_constant(&self) -> bool
Returns true if the operation is an instance of LoadConstant.
Sourceimpl OpType
impl OpType
Sourcepub fn as_load_function(&self) -> Option<&LoadFunction>
pub fn as_load_function(&self) -> Option<&LoadFunction>
If is an instance of LoadFunction return a reference to it.
Sourcepub fn is_load_function(&self) -> bool
pub fn is_load_function(&self) -> bool
Returns true if the operation is an instance of LoadFunction.
Sourceimpl OpType
impl OpType
Sourcepub fn as_extension_op(&self) -> Option<&ExtensionOp>
pub fn as_extension_op(&self) -> Option<&ExtensionOp>
If is an instance of ExtensionOp return a reference to it.
Sourcepub fn is_extension_op(&self) -> bool
pub fn is_extension_op(&self) -> bool
Returns true if the operation is an instance of ExtensionOp.
Sourceimpl OpType
impl OpType
Sourcepub fn as_dataflow_block(&self) -> Option<&DataflowBlock>
pub fn as_dataflow_block(&self) -> Option<&DataflowBlock>
If is an instance of DataflowBlock return a reference to it.
Sourcepub fn is_dataflow_block(&self) -> bool
pub fn is_dataflow_block(&self) -> bool
Returns true if the operation is an instance of DataflowBlock.
Sourceimpl OpType
impl OpType
Sourcepub fn as_exit_block(&self) -> Option<&ExitBlock>
pub fn as_exit_block(&self) -> Option<&ExitBlock>
If is an instance of ExitBlock return a reference to it.
Sourcepub fn is_exit_block(&self) -> bool
pub fn is_exit_block(&self) -> bool
Returns true if the operation is an instance of ExitBlock.
Sourceimpl OpType
impl OpType
Sourcepub fn as_tail_loop(&self) -> Option<&TailLoop>
pub fn as_tail_loop(&self) -> Option<&TailLoop>
If is an instance of TailLoop return a reference to it.
Sourcepub fn is_tail_loop(&self) -> bool
pub fn is_tail_loop(&self) -> bool
Returns true if the operation is an instance of TailLoop.
Sourceimpl OpType
impl OpType
Sourcepub fn as_conditional(&self) -> Option<&Conditional>
pub fn as_conditional(&self) -> Option<&Conditional>
If is an instance of Conditional return a reference to it.
Sourcepub fn is_conditional(&self) -> bool
pub fn is_conditional(&self) -> bool
Returns true if the operation is an instance of Conditional.
Sourceimpl OpType
impl OpType
Sourcepub fn other_port_kind(&self, dir: Direction) -> Option<EdgeKind>
pub fn other_port_kind(&self, dir: Direction) -> Option<EdgeKind>
The edge kind for the non-dataflow ports of the operation, not described by the signature.
If not None, a single extra port of that kind will be present on the given direction after any dataflow or constant ports.
Sourcepub fn static_port_kind(&self, dir: Direction) -> Option<EdgeKind>
pub fn static_port_kind(&self, dir: Direction) -> Option<EdgeKind>
The edge kind for the static ports of the operation, not described by the dataflow signature.
If not None, an extra input port of that kind will be present on the
given direction after any dataflow ports and before any
OpType::other_port_kind ports.
Sourcepub fn port_kind(&self, port: impl Into<Port>) -> Option<EdgeKind>
pub fn port_kind(&self, port: impl Into<Port>) -> Option<EdgeKind>
Returns the edge kind for the given port.
The result may be a value port, a static port, or a non-dataflow port.
See OpType::dataflow_signature, OpType::static_port_kind, and
OpType::other_port_kind.
Sourcepub fn other_port(&self, dir: Direction) -> Option<Port>
pub fn other_port(&self, dir: Direction) -> Option<Port>
The non-dataflow port for the operation, not described by the signature.
See [OpType::other_port_kind].
Returns None if there is no such port, or if the operation defines multiple non-dataflow ports.
Sourcepub fn other_input_port(&self) -> Option<IncomingPort>
pub fn other_input_port(&self) -> Option<IncomingPort>
The non-dataflow input port for the operation, not described by the signature.
See [OpType::other_port].
Sourcepub fn other_output_port(&self) -> Option<OutgoingPort>
pub fn other_output_port(&self) -> Option<OutgoingPort>
The non-dataflow output port for the operation, not described by the signature.
See [OpType::other_port].
Sourcepub fn static_port(&self, dir: Direction) -> Option<Port>
pub fn static_port(&self, dir: Direction) -> Option<Port>
If the op has a static port, the port of that input.
See OpType::static_input_port and OpType::static_output_port.
Sourcepub fn static_input_port(&self) -> Option<IncomingPort>
pub fn static_input_port(&self) -> Option<IncomingPort>
If the op has a static input (Call, LoadConstant, and LoadFunction), the port of
that input.
Sourcepub fn static_output_port(&self) -> Option<OutgoingPort>
pub fn static_output_port(&self) -> Option<OutgoingPort>
Sourcepub fn value_ports(&self, dir: Direction) -> impl DoubleEndedIterator
pub fn value_ports(&self, dir: Direction) -> impl DoubleEndedIterator
Return the dataflow value ports for the given direction.
See OpType::value_input_ports and OpType::value_output_ports.
Sourcepub fn value_input_ports(&self) -> impl DoubleEndedIterator
pub fn value_input_ports(&self) -> impl DoubleEndedIterator
Return the dataflow value input ports for the given direction.
Sourcepub fn value_output_ports(&self) -> impl DoubleEndedIterator
pub fn value_output_ports(&self) -> impl DoubleEndedIterator
Return the dataflow value output ports for the given direction.
Sourcepub fn value_port_count(&self, dir: Direction) -> usize
pub fn value_port_count(&self, dir: Direction) -> usize
The number of Value ports in given direction.
Sourcepub fn value_input_count(&self) -> usize
pub fn value_input_count(&self) -> usize
The number of Value input ports.
Sourcepub fn value_output_count(&self) -> usize
pub fn value_output_count(&self) -> usize
The number of Value output ports.
Sourcepub fn port_count(&self, dir: Direction) -> usize
pub fn port_count(&self, dir: Direction) -> usize
Returns the number of ports for the given direction.
Sourcepub fn input_count(&self) -> usize
pub fn input_count(&self) -> usize
Returns the number of inputs ports for the operation.
Sourcepub fn output_count(&self) -> usize
pub fn output_count(&self) -> usize
Returns the number of outputs ports for the operation.
Sourcepub fn is_container(&self) -> bool
pub fn is_container(&self) -> bool
Checks whether the operation can contain children nodes.
Sourcepub fn cast<T>(&self) -> Option<T>where
T: MakeExtensionOp,
pub fn cast<T>(&self) -> Option<T>where
T: MakeExtensionOp,
Cast to an extension operation.
Returns None if the operation is not of the requested type.
Sourcepub fn extension_id(&self) -> Option<&IdentList>
pub fn extension_id(&self) -> Option<&IdentList>
Returns the extension where the operation is defined, if any.
Sourcepub fn used_extensions(
&self,
) -> Result<ExtensionRegistry, ExtensionCollectionError>
pub fn used_extensions( &self, ) -> Result<ExtensionRegistry, ExtensionCollectionError>
Returns a registry with all the extensions required by the operation.
This includes the operation extension in OpType::extension_id, and any
extension required by the operation’s signature types.