UntuplePass

Struct UntuplePass 

pub struct UntuplePass { /* private fields */ }
A pass that removes unnecessary MakeTuple operations immediately followed by UnpackTuples.

If the tuple output is consumed by other operations, only the UnpackTuples are removed and their outputs are connected to the original values accordingly.

Currently only unpack operations in the same region as the MakeTuple are removed. This may be extended in the future.

Removes MakeTuple operations that are not consumed by any other operations.

Ignores pack/unpack nodes with order edges.

Implementations

Source

impl UntuplePass

pub fn all_rewrites<H: HugrView<Node = Node>>( &self, hugr: &H, ) -> Vec<SimpleReplacement<H::Node>>

Find tuple pack operations followed by tuple unpack operations and generate rewrites to remove them.

The returned rewrites are guaranteed to be independent of each other.

Returns an iterator over the rewrites.